CreateBudgetActionResponse class

Constructors

CreateBudgetActionResponse({required String accountId, required String actionId, required String budgetName})
CreateBudgetActionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String
final
actionId → String
A system-generated universally unique identifier (UUID) for the action.
final
budgetName → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited