Definition class

Specifies all of the type-specific parameters.

Constructors

Definition({IamActionDefinition? iamActionDefinition, ScpActionDefinition? scpActionDefinition, SsmActionDefinition? ssmActionDefinition})
Definition.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iamActionDefinition → IamActionDefinition?
The AWS Identity and Access Management (IAM) action definition details.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scpActionDefinition → ScpActionDefinition?
The service control policies (SCPs) action definition details.
final
ssmActionDefinition → SsmActionDefinition?
The AWS Systems Manager (SSM) action definition details.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited