NotificationWithSubscribers class

A notification with subscribers. A notification can have one SNS subscriber and up to 10 email subscribers, for a total of 11 subscribers.

Constructors

NotificationWithSubscribers({required Notification notification, required List<Subscriber> subscribers})

Properties

hashCode → int
The hash code for this object.
no setterinherited
notification → Notification
The notification that is associated with a budget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscribers → List<Subscriber>
A list of subscribers who are subscribed to this notification.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited